library(tidyverse)
library(infer) # Contains rep_slice_sample() function

dragon_population <- read_csv("http://www.cknuckles.com/statsprogramming/data/dragon_data.csv" )
dragon_population

dragon_population %>%
  rep_slice_sample(n = 75, reps = 10000)      # 10,000 independent samples of size 75

means_10000_samples <- dragon_population %>%
  rep_slice_sample(n = 75, reps = 10000) %>%  # 10,000 independent samples each of size 75
  group_by(replicate) %>%                     # subset the date into individual samples
  summarize(
    sample_mean = mean(wingspan)              # separate mean for each sample
  )
means_10000_samples


# Frequency Histogram
ggplot(means_10000_samples, mapping = aes(x = sample_mean)) +
  geom_histogram(bins=50, color="white") +
  scale_x_continuous(limits = c(6, 9), breaks = c(6,6.6,7,7.34,8,9))


# Relative Frequency Histogram
# ggplot automatically populates count, which stat(count) / sum(count) turns into a proportion.
ggplot(means_10000_samples, mapping = aes(x = sample_mean, y = stat(count)/sum(count))) +
  geom_histogram(bins=50, color="white") +
  scale_x_continuous(limits = c(6, 9), breaks = c(6,6.6,7,7.2,7.34,7.5,8,9)) +
  labs(y = "Probability")


# Empirical Sampling Distribution mean and standard deviation
means_10000_samples %>%
  summarize(
    samp_dist_mean = mean(sample_mean),
    SE = sd(sample_mean)
  )

