library(tidyverse)
library(infer) # Contains rep_slice_sample() function

dragon_population <- read_csv("http://www.cknuckles.com/statsprogramming/data/dragon_data.csv" )
dragon_population

# Simulated Sampling Dist
########################################################################################

means_10000_samples <- dragon_population %>%
  rep_slice_sample(n = 75, reps = 10000) %>%  # 10,000 independent samples each of size 75
  group_by(replicate) %>%                     # subset the date into individual samples
  summarize(
    sample_mean = mean(wingspan)              # separate mean for each sample
  )

# Relative Frequency Histogram
ggplot(means_10000_samples, mapping = aes(x = sample_mean)) +
  geom_histogram(bins=50, color="white", aes(y = stat(count) / sum(count))) +
  # ggplot automatically populates count, which stat(count) / sum(count) turns into a proportion.
  scale_x_continuous(limits = c(6, 9), breaks = c(6,6.6,7,7.2,7.34,7.5,8,9)) +
  labs(y = "Probability")


# Empirical Sampling Distribution mean and standard deviation
means_10000_samples %>%
  summarize(
    samp_dist_mean = mean(sample_mean),
    SE = sd(sample_mean)
  )

# Theory-Based Sampling Dist
########################################################################################

# Dragon Population Parameters
mu <- 7.34
sigma <-  2.23

# Standard Deviation of n=75 Sampling Distribution
SE <- sigma/sqrt(75)
SE

# Plot of n=75 Sampling Distribution for Dragon Population
ggplot(tibble(xlim = c(mu-3, mu+3)) , aes(x = xlim)) +
  stat_function(fun = dnorm, args = list(mean = mu, sd = SE))
